<b> installation</b>
```bash
$ pip3 install nulis
```
<b> how to use</b>
```bash
$ python3
```
```python
>>> from tulis import tulis
>>> tulis=tulis("Nama : Krypton-Byte")
>>> for i in tulis.tulis:
>>>     i.show() #show image
>>>     i.save("catatan.jpg") #save the results
```
Automatic support for new lines when it reaches the right end and adding paper when not enough<br>
<b>Result</b><br>
<img src="catatan.jpg">
